# aio9p

Asyncio-based bindings for the 9P protocol. Work in progress.

Working examples for the 9P2000 and 9P2000.u dialects are implemented in
aio9p.example .

## Features

* 9P2000 client and server
* 9P2000.u client and server
* Transports: TCP, domain sockets

## TODO

### Documentation
- Client examples.

### Features
- Support for the 9P2000.L dialect

### Testing
- Significantly expanded unit testing
- Expanded integration tests
- Benchmarking
